@@ -2,14 +2,6 @@ class DankCordException(BaseException):
     pass
 
 
-class InvalidCommand(DankCordException):
-    pass
-
-
-class InvalidComponent(DankCordException):
-    pass
-
-
 class InvalidToken(DankCordException):
     pass
 
@@ -22,12 +14,13 @@ class UnknownChannel(DankCordException):
     pass
 
 
-class NonceTimeout(DankCordException):
-    pass
-
-
 class NoCommands(DankCordException):
     pass
 
+
 class DataAccessFailure(DankCordException):
+    pass
+
+
+class InvalidFormBody(DankCordException):
     pass
\ No newline at end of file
